@@ -1,26 +1,19 @@
 # -*- coding: utf-8 -*-
 """
-MIT License
+  Copyright 2022 Mitchell Isaac Parker
 
-Copyright (c) 2022 Mitchell Isaac Parker
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
+       http://www.apache.org/licenses/LICENSE-2.0
 
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
 """
 
 import os
@@ -46,8 +39,7 @@ def main(args):
 
     classify = args.classify
     build = args.build
-    # cluster = args.cluster
-    # plot = args.plot
+    #cluster = args.cluster
     gui = args.gui
 
     out = args.out
@@ -79,20 +71,12 @@ def main(args):
         )
 
     # elif cluster is not None:
-    #     from rascore.util.pipelines.prep_rascore import prep_rascore
-    #     from rascore.util.pipelines.cluster_rascore import cluster_rascore
+    #     from util.pipelines.prep_rascore import prep_rascore
+    #     from util.pipelines.cluster_rascore import cluster_rascore
 
     #     prep_rascore(build_path=cluster)
     #     cluster_rascore(cluster, out_path=out, num_cpu=cpu)
 
-    # elif plot is not None:
-
-    #     from rascore.util.pipelines.prep_rascore import prep_rascore
-    #     from rascore.util.pipelines.plot_rascore import plot_rascore
-
-    #     prep_rascore(build_path=plot)
-    #     plot_rascore(plot, out_path=out, num_cpu=cpu)
-
     elif gui is not None:
         if gui is not True:
 
@@ -118,16 +102,16 @@ def main(args):
 
 def cli(args=None):
 
-    print(pyfiglet.figlet_format("rascore"))
-    print("A tool for analyzing the conformations of RAS structures\n")
-    print("Author: Mitchell Isaac Parker <mitch.isaac.parker@gmail.com>")
-    print("License: MIT License\n")
+    print(pyfiglet.figlet_format("Rascore"))
+    print("A tool for analyzing RAS protein structures\n")
+    print("Author: Mitchell Isaac Parker <mip34@drexel.edu>")
+    print("License: Apache License 2.0\n")
 
     if not args:
         args = sys.argv[1:]
 
     parser = argparse.ArgumentParser(
-        description="rascore: A tool for analyzing the conformations of RAS structures"
+        description="Rascore: A tool for analyzing RAS protein structures"
     )
 
     group = parser.add_mutually_exclusive_group()
@@ -136,7 +120,7 @@ def cli(args=None):
         "--classify",
         nargs="+",
         required=False,
-        help="path to coordinate file(s) of RAS structures to conformationally classify provided as a space-separated list, line-sepated file, or tab-seperated file (output files saved to rascore_classify in current working directory unless an output directory path is specified)",
+        help="path to coordinate files of RAS structures to conformationally classify provided as a space-separated list, line-sepated file, or tab-seperated file (output files saved to rascore_classify in current working directory unless an output directory path is specified)",
     )
     group.add_argument(
         "-build",
@@ -154,13 +138,6 @@ def cli(args=None):
     #     required=False,
     #     help="path to rascore database directory (output files saved to rascore_cluster in current working directory unless an output directory path is specified)",
     # )
-    # group.add_argument(
-    #     "-plot",
-    #     "--plot",
-    #     type=str,
-    #     required=False,
-    #     help="path to rascore database directory (output files saved to rascore_plot in current working directory unless an output directory path is specified)",
-    # )
     group.add_argument(
         "-gui",
         "--gui",
@@ -168,7 +145,7 @@ def cli(args=None):
         const=True,
         nargs="?",
         required=False,
-        help="path to rascore database directory (can run limited version if not specified) for running the rascore GUI application (output files saved to rascore_app in current working directory unless an output directory path is specified)",
+        help="optional path to rascore database directory (can run without) for running the rascore GUI application",
     )
     parser.add_argument(
         "-out",
