@@ -1,26 +1,19 @@
 # -*- coding: utf-8 -*-
 """
-MIT License
+  Copyright 2022 Mitchell Isaac Parker
 
-Copyright (c) 2022 Mitchell Isaac Parker
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
+       http://www.apache.org/licenses/LICENSE-2.0
 
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
 """
 
 import gzip
@@ -43,9 +36,25 @@ from Bio.Data.SCOPData import protein_letters_3to1 as aa3to1
 
 import math
 
-from .seq import *
-from .table import *
-from .lst import *
+from .seq import pair_seq_aln
+from .table import (
+    fix_val,
+    replace_str,
+    extract_int,
+    extract_str,
+    make_dict,
+    is_int,
+    is_str,
+)
+from .lst import (
+    str_to_lst,
+    res_to_lst,
+    type_lst,
+    sort_lst,
+    lst_nums,
+    lst_unique,
+    lst_inter,
+)
 
 
 aa_lst = [
