@@ -1,26 +1,19 @@
 # -*- coding: utf-8 -*-
 """
-MIT License
+  Copyright 2022 Mitchell Isaac Parker
 
-Copyright (c) 2022 Mitchell Isaac Parker
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
+       http://www.apache.org/licenses/LICENSE-2.0
 
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
 """
 
 import pandas as pd
@@ -181,7 +174,7 @@ def make_legend_plot(
 def make_venn_plot(
     lst_1,
     lst_2,
-    plot_path,
+    plot_path=None,
     label_1=None,
     label_2=None,
     color_1=None,
@@ -225,28 +218,32 @@ def make_venn_plot(
 
     for text in v.subset_labels:
 
-        if text.get_text() == "0\n(0%)":
-            text.set_text("")
-        else:
-            text.set_fontsize(font_size * 0.75)
-            text.set_color(count_color)
-            bbox_extra_artists += (text,)
+        if text is not None:
+            if text.get_text() == "0\n(0%)":
+                text.set_text("")
+            else:
+                text.set_fontsize(font_size * 0.75)
+                text.set_color(count_color)
+                bbox_extra_artists += (text,)
 
     if plot_title is not None:
         title = fig.suptitle(plot_title, fontsize=font_size)
         bbox_extra_artists += (title,)
 
-    append_file_path(plot_path)
+    if plot_path is None:
+        return fig
+    else:
+        append_file_path(plot_path)
 
-    plt.savefig(
-        plot_path,
-        format="pdf",
-        bbox_extra_artists=bbox_extra_artists,
-        bbox_inches="tight",
-        pad_inches=0.0,
-        dpi=600,
-    )
-    plt.close()
+        plt.savefig(
+            plot_path,
+            format="pdf",
+            bbox_extra_artists=bbox_extra_artists,
+            bbox_inches="tight",
+            pad_inches=0.0,
+            dpi=600,
+        )
+        plt.close()
 
 
 def make_stacked_barplot(
