@@ -1,26 +1,19 @@
 # -*- coding: utf-8 -*-
 """
-MIT License
+  Copyright 2022 Mitchell Isaac Parker
 
-Copyright (c) 2022 Mitchell Isaac Parker
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
+       http://www.apache.org/licenses/LICENSE-2.0
 
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
 """
 
 import os
@@ -30,7 +23,7 @@ from datetime import datetime
 
 from ..pipelines.classify_rascore import classify_rascore
 
-from ..constants.conf import sw1_name, sw2_name, loop_resid_dict
+from ..constants.conf import sw1_name, sw2_name, y32_name, y71_name
 from ..constants.nuc import nuc_class_dict, gtp_name
 from ..constants.gene import uniprot_acc_lst, swiss_id_lst, gene_class_dict
 from ..constants.mut import mut_class_lst, other_mut_name
@@ -48,8 +41,8 @@ from ..constants.prot import (
     gef_name,
     prot_pfam_dict,
     prot_class_dict,
-    gef_rem_name,
-    gef_cdc_name,
+    rem_name,
+    cdc_name,
     nano_name,
     mult_prot_name,
 )
@@ -81,6 +74,7 @@ from ..functions.path import (
     get_dir_path,
     copy_path,
     load_json,
+    path_exists,
     save_table,
     save_json,
     get_file_path,
@@ -132,7 +126,6 @@ from ..functions.col import (
     prot_col,
     bio_lig_col,
     nuc_class_col,
-    class_col_lst,
     rcsb_path_col,
     bound_prot_pfam_col,
     complete_col,
@@ -175,11 +168,9 @@ def update_prep(out_path=None, past_df=None, num_cpu=1):
     if delete_paths:
         delete_path(sifts_json_path)
         delete_path(dih_json_path)
+        past_df = None
 
-    if len(df) == 0:
-        if past_df is not None:
-            save_table(entry_table_path, past_df)
-    else:
+    if len(df) > 0:
         pdb_id_lst = lst_col(df, pdb_id_col, unique=True)
 
         past_sifts_dict = load_json(sifts_json_path)
@@ -203,30 +194,36 @@ def update_prep(out_path=None, past_df=None, num_cpu=1):
         if past_sifts_dict is not None:
             sifts_dict = merge_dicts([sifts_dict, past_sifts_dict])
         save_json(sifts_json_path, sifts_dict)
+        
+        try:
+            df = load_table(entry_table_path)
 
-        df = load_table(entry_table_path)
+            core_path_lst = lst_col(df, core_path_col, unique=True)
+            dih_dict = prep_dih(coord_paths=core_path_lst, num_cpu=num_cpu)
 
-        core_path_lst = lst_col(df, core_path_col, unique=True)
-        dih_dict = prep_dih(coord_paths=core_path_lst, num_cpu=num_cpu)
+            past_dih_dict = load_json(dih_json_path)
+            if past_dih_dict is not None:
+                dih_dict = merge_dicts([dih_dict, past_dih_dict])
+            save_json(dih_json_path, dih_dict)
 
-        past_dih_dict = load_json(dih_json_path)
-        if past_dih_dict is not None:
-            dih_dict = merge_dicts([dih_dict, past_dih_dict])
-        save_json(dih_json_path, dih_dict)
+            if past_df is not None:
+                if (
+                    len(
+                        [
+                            x
+                            for x in [bound_lig_col, bound_prot_chainid_col]
+                            if x not in list(past_df.columns)
+                        ]
+                    )
+                    == 0
+                ):
+                    df = pd.concat([df, past_df], sort=False)
+                    df = df.reset_index(drop=True)
+                    save_table(entry_table_path, df)
+        except:
+            if past_df is not None:
+                save_table(entry_table_path, past_df)
 
-        if past_df is not None:
-            if (
-                len(
-                    [
-                        x
-                        for x in [bound_lig_col, bound_prot_chainid_col]
-                        if x not in list(past_df.columns)
-                    ]
-                )
-                == 0
-            ):
-                df = pd.concat([df, past_df], sort=False)
-                save_table(entry_table_path, df)
 
 
 def update_annot(pdbaa_fasta_path, out_path=None, past_df=None, num_cpu=1):
@@ -241,6 +238,8 @@ def update_annot(pdbaa_fasta_path, out_path=None, past_df=None, num_cpu=1):
                 [
                     x
                     for x in [
+                        gene_class_col,
+                        nuc_class_col,
                         mut_class_col,
                         pharm_class_col,
                         match_class_col,
@@ -254,10 +253,7 @@ def update_annot(pdbaa_fasta_path, out_path=None, past_df=None, num_cpu=1):
         ):
             df = mask_unequal(df, pdb_id_col, lst_col(past_df, pdb_id_col))
 
-    if len(df) == 0:
-        if past_df is not None:
-            save_table(entry_table_path, past_df)
-    else:
+    if len(df) > 0:
         df = annot_mut(
             df=df,
             uniprot_accs=uniprot_acc_lst,
@@ -325,17 +321,26 @@ def update_annot(pdbaa_fasta_path, out_path=None, past_df=None, num_cpu=1):
                     nuc_class = df.at[index, nuc_class_col]
                     prot_class += "."
                     if nuc_class == gtp_name:
-                        prot_class += gef_rem_name
+                        prot_class += rem_name
                     else:
-                        prot_class += gef_cdc_name
+                        prot_class += cdc_name
             df.at[index, prot_class_col] = prot_class
 
         if (
             past_df is not None
-            and len([x for x in class_col_lst if x not in list(past_df.columns)]) == 0
+            and len([x for x in [
+                        gene_class_col,
+                        nuc_class_col,
+                        mut_class_col,
+                        pharm_class_col,
+                        match_class_col,
+                        prot_class_col,
+                        cf_col,
+                    ] if x not in list(past_df.columns)]) == 0
         ):
             df[complete_col] = str(False)
             df = pd.concat([df, past_df], sort=False)
+            df = df.reset_index(drop=True)
             save_table(entry_table_path, df)
 
         rcsb_path_lst = lst_col(df, rcsb_path_col, unique=True)
@@ -357,18 +362,16 @@ def update_interf(out_path=None, past_df=None, num_cpu=1):
     df = load_table(entry_table_path)
 
     delete_paths = True
-    if past_df is not None and interf_class_col in list(past_df.columns):
+    if past_df is not None and interf_class_col in list(past_df.columns) and path_exists(interf_json_path) and path_exists(interf_table_path):
         df = mask_unequal(df, pdb_id_col, lst_col(past_df, pdb_id_col))
         delete_paths = False
 
     if delete_paths:
         delete_path(interf_json_path)
         delete_path(interf_table_path)
+        past_df = None
 
-    if len(df) == 0:
-        if past_df is not None:
-            save_table(entry_table_path, past_df)
-    else:
+    if len(df) > 0:
         xray_df = mask_equal(df, method_col, "XRAY")
 
         coord_path_lst = lst_col(xray_df, renum_path_col, unique=True)
@@ -404,6 +407,7 @@ def update_interf(out_path=None, past_df=None, num_cpu=1):
         past_interf_df = load_table(interf_table_path)
         if past_interf_df is not None and interf_class_col in list(past_df.columns):
             interf_df = pd.concat([interf_df, past_interf_df], sort=False)
+            interf_df = interf_df.reset_index(drop=True)
         save_table(interf_table_path, interf_df)
 
         interf_pdb_id_lst = lst_col(interf_df, pdb_id_col)
@@ -413,10 +417,10 @@ def update_interf(out_path=None, past_df=None, num_cpu=1):
             .fillna(none_dimer_name)
         )
 
-        if past_df is not None:
-            if interf_class_col in list(past_df.columns):
-                df[complete_col] = str(False)
-                df = pd.concat([df, past_df], sort=False)
+        if past_df is not None and interf_class_col in list(past_df.columns):
+            df[complete_col] = str(False)
+            df = pd.concat([df, past_df], sort=False)
+            df = df.reset_index(drop=True)
 
         save_table(entry_table_path, df)
 
@@ -430,19 +434,16 @@ def update_pocket(out_path=None, past_df=None, num_cpu=1):
     df = load_table(entry_table_path)
 
     delete_paths = True
-    if past_df is not None:
-        if pocket_class_col in list(past_df.columns):
-            df = mask_unequal(df, pdb_id_col, lst_col(past_df, pdb_id_col))
-            delete_paths = False
+    if past_df is not None and pocket_class_col in list(past_df.columns) and path_exists(pocket_json_path) and path_exists(pocket_table_path):
+        df = mask_unequal(df, pdb_id_col, lst_col(past_df, pdb_id_col))
+        delete_paths = False
 
     if delete_paths:
         delete_path(pocket_json_path)
         delete_path(pocket_table_path)
+        past_df = None
 
-    if len(df) == 0:
-        if past_df is not None:
-            save_table(entry_table_path, past_df)
-    else:
+    if len(df) > 0:
         coord_path_lst = [x.replace(".cif", ".pdb") for x in lst_col(df, core_path_col)]
 
         chainid_dict = dict()
@@ -465,10 +466,10 @@ def update_pocket(out_path=None, past_df=None, num_cpu=1):
             pocket_dict = merge_dicts([pocket_dict, past_pocket_dict])
         save_json(pocket_json_path, pocket_dict)
 
-        if past_df is not None:
-            if pocket_class_col in list(past_df.columns):
-                df[complete_col] = str(False)
-                df = pd.concat([df, past_df], sort=False)
+        if past_df is not None and pocket_class_col in list(past_df.columns):
+            df[complete_col] = str(False)
+            df = pd.concat([df, past_df], sort=False)
+            df = df.reset_index(drop=True)
 
         temp_df = build_pocket_table(
             df=df,
@@ -486,6 +487,7 @@ def update_pocket(out_path=None, past_df=None, num_cpu=1):
             bound_df[pocket_type_col] = pharm_name
             bound_df[pocket_site_col] = pharm_name
             pocket_df = pd.concat([pocket_df, bound_df], sort=False)
+            pocket_df = pocket_df.reset_index(drop=True)
 
             search_cont_lst = lst_col(bound_df, pocket_cont_col)
             search_cont_lst = [str_to_lst(x) for x in search_cont_lst]
@@ -504,6 +506,7 @@ def update_pocket(out_path=None, past_df=None, num_cpu=1):
                 )
                 unbound_df[pocket_site_col] = pharm_name
                 pocket_df = pd.concat([pocket_df, unbound_df], sort=False)
+                pocket_df = pocket_df.reset_index(drop=True)
 
         other_df = mask_unequal(
             temp_df, pocket_id_col, lst_col(pocket_df, pocket_id_col)
@@ -514,6 +517,7 @@ def update_pocket(out_path=None, past_df=None, num_cpu=1):
         other_df[pocket_site_col] = other_pharm_name
 
         pocket_df = pd.concat([pocket_df, other_df], sort=False)
+        pocket_df = pocket_df.reset_index(drop=True)
 
         save_table(pocket_table_path, pocket_df)
 
@@ -568,7 +572,21 @@ def update_classify(out_path=None, past_df=None, num_cpu=1):
     df = load_table(entry_table_path)
 
     if past_df is not None:
-        if sw1_name in list(past_df.columns) and sw2_name in list(past_df.columns):
+        if (
+            len(
+                [
+                    x
+                    for x in [
+                        sw1_name,
+                        sw2_name,
+                        y32_name,
+                        y71_name
+                    ]
+                    if x not in list(past_df.columns)
+                ]
+            )
+            == 0
+        ):
             df = mask_unequal(df, pdb_id_col, lst_col(past_df, pdb_id_col))
 
     dih_dict = load_json(dih_json_path)
@@ -585,17 +603,32 @@ def update_classify(out_path=None, past_df=None, num_cpu=1):
 
         result_df = load_table(get_file_path(result_table_file, dir_path=classify_path))
 
-        for loop_name in list(loop_resid_dict.keys()):
-            df[loop_name] = df[pdb_id_col].map(
-                make_dict(lst_col(result_df, pdb_id_col), lst_col(result_df, loop_name))
+        for col in [sw1_name, sw2_name, y32_name, y71_name]:
+            df[col] = df[pdb_id_col].map(
+                make_dict(lst_col(result_df, pdb_id_col), lst_col(result_df, col))
             )
 
-    if past_df is not None:
-        if sw1_name in list(past_df.columns) and sw2_name in list(past_df.columns):
-            df[complete_col] = str(False)
-            df = pd.concat([df, past_df], sort=False)
+        if past_df is not None:
+            if (
+                len(
+                    [
+                        x
+                        for x in [
+                            sw1_name,
+                            sw2_name,
+                            y32_name,
+                            y71_name
+                        ]
+                        if x not in list(past_df.columns)
+                    ]
+                )
+                == 0
+            ):
+                df[complete_col] = str(False)
+                df = pd.concat([df, past_df], sort=False)
+                df = df.reset_index(drop=True)
 
-    save_table(entry_table_path, df)
+        save_table(entry_table_path, df)
 
 
 def build_rascore(out_path=None, pdbaa_fasta_path=None, num_cpu=1):
@@ -687,12 +720,32 @@ def build_rascore(out_path=None, pdbaa_fasta_path=None, num_cpu=1):
 
     save_table(entry_table_path, df)
 
+    ref_df = df.set_index(pdb_id_col)
+
+    pocket_df = load_table(pocket_table_path)
+    interf_df = load_table(interf_table_path)
+
+    for col in list(ref_df.columns):
+        if col not in list(pocket_df.columns):
+            for index in list(pocket_df.index.values):
+                pocket_df.at[index, col] = ref_df.at[pocket_df.at[index, pdb_id_col], col]
+        if col not in list(interf_df.columns):
+            for index in list(interf_df.index.values):
+                interf_df.at[index, col] = ref_df.at[interf_df.at[index, pdb_id_col], col]
+
+    save_table(pocket_table_path, pocket_df)
+    save_table(interf_table_path, interf_df)
+
     for file_path in [
         entry_table_path,
         pocket_table_path,
         interf_table_path,
         dih_json_path,
     ]:
+        print(get_file_path(
+                get_file_name(file_path),
+                dir_path=get_neighbor_path(__file__, pipelines_str, data_str),
+            ))
         copy_path(
             file_path,
             get_file_path(
