@@ -1,26 +1,19 @@
 # -*- coding: utf-8 -*-
 """
-MIT License
+  Copyright 2022 Mitchell Isaac Parker
 
-Copyright (c) 2022 Mitchell Isaac Parker
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
+       http://www.apache.org/licenses/LICENSE-2.0
 
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
 """
 
 import os
@@ -42,6 +35,7 @@ from ..functions.table import (
     type_lst,
     merge_tables,
     make_dict,
+    fix_col,
     core_path_col,
     chainid_col,
     modelid_col,
@@ -66,12 +60,11 @@ from ..functions.coord import load_coord, get_modelid, get_chainid
 from ..functions.lig import lig_col_lst
 from ..functions.col import (
     id_col,
-    pharm_class_col,
-    pharm_lig_site_col,
     nuc_class_col,
     bio_lig_col,
     cluster_col,
     hb_status_col,
+    complete_col,
 )
 from ..functions.file import (
     cluster_table_file,
@@ -84,33 +77,34 @@ from ..functions.file import (
 from ..constants.nuc import (
     gtp_name,
     nuc_class_dict,
-    nuc_class_lst,
     nuc_class_dict,
     gtp_atomids,
+    nuc_class_lst,
 )
 from ..constants.pharm import (
-    pharm_site_dict,
-    pharm_match_dict,
-    sp2_name,
-    sp12_name,
-    none_pharm_name,
-    other_pharm_name,
+    pharm_site_dict,    
 )
 from ..constants.conf import (
-    loop_resid_dict,
+    y32_name,
+    y71_name,
     sw1_name,
     sw2_name,
-    sw1_gtp_name,
-    sw1_gtp_dir_name,
-    sw1_gtp_wat_name,
-    sw1_gtp_no_name,
-    sw1_gtp_dict,
-    conf_color_dict,
+    in_name,
+    out_name,
+    noise_name,
+    outlier_name,
+    disorder_name,
+    conf_color_dict
 )
 from ..constants.pml import sup_resids, show_resids
 
 
-def classify_rascore(file_paths, out_path=None, dih_dict=None, num_cpu=1):
+def classify_rascore(file_paths, out_path=None, dih_dict=None, 
+                    sw1_resids="25-40", sw2_resids="56-76", 
+                    y32_resid=32, y71_resid=71, 
+                    g12_resid=12, v9_resid=9,
+                    y32_dist=10.5, y71_dist=8.75,
+                    num_cpu=1):
 
     if out_path is None:
         out_path = f"{os.getcwd()}/{rascore_str}_{classify_str}"
@@ -167,10 +161,17 @@ def classify_rascore(file_paths, out_path=None, dih_dict=None, num_cpu=1):
 
         df = pd.concat([df, temp_df], sort=False)
 
-    if len(df) > 0:
+    if len(df) == 0:
+        print('No structures to classify.')
+    else:
+        df = df.reset_index(drop=True)
 
         df_col_lst = list(df.columns)
 
+        for col in [y32_name, y71_name, sw1_name, sw2_name]:
+            if col in df_col_lst:
+                del df[col]
+
         missing_col_lst = [
             x for x in [core_path_col, modelid_col, chainid_col] if x not in df_col_lst
         ]
@@ -188,24 +189,64 @@ def classify_rascore(file_paths, out_path=None, dih_dict=None, num_cpu=1):
                 df = annot_lig(
                     df=df,
                     site_dict=pharm_site_dict,
-                    match_dict=pharm_match_dict,
                     num_cpu=num_cpu,
                 )
 
-            if pharm_class_col not in df_col_lst:
-                for index in list(df.index.values):
-                    pharm_class = df.at[index, pharm_lig_site_col]
-                    if pharm_class not in [sp2_name, sp12_name, none_pharm_name]:
-                        pharm_class = other_pharm_name
-                    df.at[index, pharm_class_col] = pharm_class
-
             if nuc_class_col not in df_col_lst:
                 df[nuc_class_col] = df[bio_lig_col].map(nuc_class_dict).fillna(gtp_name)
 
             if dih_dict is None:
                 dih_dict = prep_dih(coord_path_lst, num_cpu=num_cpu)
 
-            for loop_name, loop_resids in loop_resid_dict.items():
+            dist_df = build_dist_table(
+                df,
+                x_resids=[y32_resid, y71_resid],
+                y_resids=[g12_resid, v9_resid],
+                x_atomids=['OH','OH'],
+                y_atomids=['CA','CA'],
+                atom_dist_col_lst=[y32_name, y71_name]
+            )
+
+            dist_dict = {y32_name: y32_dist, y71_name: y71_dist}
+
+            for resid_name in [y32_name, y71_name]:
+                dist_df[resid_name] = dist_df[resid_name].map(str)
+
+            for index in list(dist_df.index.values):
+
+                nuc_class = dist_df.at[index, nuc_class_col]
+
+                for resid_name in [y32_name, y71_name]:
+
+                    atom_dist = float(dist_df.at[index, resid_name])
+
+                    if atom_dist == 999.00:
+                        group_name = disorder_name
+                    else:
+                        group_name = resid_name
+                        if atom_dist <= dist_dict[resid_name]:
+                            group_name += in_name
+                        else:
+                            group_name += out_name
+
+                    dist_df.at[index, resid_name] = group_name
+
+            for resid_name in [y32_name, y71_name]:
+
+                merge_df = dist_df.loc[
+                    :, [core_path_col, modelid_col, chainid_col, resid_name]
+                ]
+
+                df = merge_tables(df, merge_df)
+
+            for resid_name in [y32_name, y71_name]:
+
+                if resid_name == y32_name:
+                    loop_name = sw1_name
+                    loop_resids = sw1_resids
+                elif resid_name == y71_name:
+                    loop_name = sw2_name
+                    loop_resids = sw2_resids
 
                 cluster_loop_path = f"{cluster_path}/{loop_name}"
                 classify_loop_path = f"{out_path}/{loop_name}"
@@ -213,93 +254,86 @@ def classify_rascore(file_paths, out_path=None, dih_dict=None, num_cpu=1):
                 loop_result_df = pd.DataFrame()
                 loop_sum_df = pd.DataFrame()
 
-                for nuc_class in nuc_class_lst:
+                for group_name in lst_col(df, resid_name, unique=True):
 
-                    print(
-                        f"Classifying {loop_name} conformations in {nuc_class} structures."
-                    )
+                    group_df = mask_equal(df, resid_name, group_name)
 
-                    loop_nuc_name = f"{loop_name}_{nuc_class}"
+                    for nuc_class in nuc_class_lst:
 
-                    cluster_table_path = get_file_path(
-                        cluster_table_file,
-                        dir_str=loop_nuc_name,
-                        dir_path=cluster_loop_path,
-                    )
+                        group_nuc_df = mask_equal(group_df, nuc_class_col, nuc_class)
 
-                    fit_matrix_path = get_file_path(
-                        dih_fit_matrix_file,
-                        dir_str=loop_nuc_name,
-                        dir_path=cluster_loop_path,
-                    )
+                        group_nuc_name = f"{group_name}.{nuc_class}"
 
-                    result_table_path = get_file_path(
-                        result_table_file,
-                        dir_str=loop_nuc_name,
-                        dir_path=classify_loop_path,
-                    )
+                        print(
+                                f"Classifying {loop_name} conformations in {group_name}.{nuc_class} structures."
+                            )
 
-                    sum_table_path = get_file_path(
-                        sum_table_file,
-                        dir_str=loop_nuc_name,
-                        dir_path=classify_loop_path,
-                    )
-
-                    pred_matrix_path = get_file_path(
-                        pred_matrix_file,
-                        dir_str=loop_nuc_name,
-                        dir_path=classify_loop_path,
-                    )
-
-                    nuc_df = mask_equal(df, nuc_class_col, nuc_class)
-
-                    if len(nuc_df) > 0:
-
-                        chi1_resids = None
-                        if loop_name == sw2_name:
-                            chi1_resids = 71
-
-                        dih_df = build_dih_table(
-                            df=nuc_df,
-                            dih_dict=dih_dict,
-                            bb_resids=loop_resids,
-                            chi1_resids=chi1_resids,
+                        cluster_table_path = get_file_path(
+                            cluster_table_file,
+                            dir_str=group_nuc_name,
+                            dir_path=cluster_loop_path,
                         )
 
-                        cluster_df = load_table(cluster_table_path)
-
-                        build_dih_matrix(
-                            fit_df=cluster_df,
-                            pred_df=dih_df,
-                            max_norm_path=pred_matrix_path,
+                        fit_matrix_path = get_file_path(
+                            dih_fit_matrix_file,
+                            dir_str=group_nuc_name,
+                            dir_path=cluster_loop_path,
                         )
 
-                        fit_matrix = load_matrix(fit_matrix_path)
-                        pred_matrix = load_matrix(pred_matrix_path)
-
-                        classify_matrix(
-                            cluster_df=cluster_df,
-                            pred_df=dih_df,
-                            fit_matrix=fit_matrix,
-                            pred_matrix=pred_matrix,
-                            result_table_path=result_table_path,
-                            max_nn_dist=0.45,
-                            only_save_pred=True,
-                            reorder_class=False,
+                        result_table_path = get_file_path(
+                            result_table_file,
+                            dir_str=group_nuc_name,
+                            dir_path=classify_loop_path,
                         )
 
-                        result_df = load_table(result_table_path)
-
-                        sum_df = build_sum_table(result_df)
-
-                        save_table(result_table_path, result_df)
-                        save_table(sum_table_path, sum_df)
-
-                        loop_result_df = pd.concat(
-                            [loop_result_df, result_df], sort=False
+                        pred_matrix_path = get_file_path(
+                            pred_matrix_file,
+                            dir_str=group_nuc_name,
+                            dir_path=classify_loop_path,
                         )
-                        loop_sum_df = pd.concat([loop_sum_df, sum_df], sort=False)
 
+                        if len(group_nuc_df) > 0:
+
+                            dih_df = build_dih_table(
+                                    df=group_nuc_df,
+                                    dih_dict=dih_dict,
+                                    bb_resids=loop_resids,
+                                )
+
+                            if disorder_name not in group_nuc_name:
+
+                                cluster_df = load_table(cluster_table_path)
+
+                                build_dih_matrix(
+                                    fit_df=cluster_df,
+                                    pred_df=dih_df,
+                                    max_norm_path=pred_matrix_path,
+                                )
+
+                                fit_matrix = load_matrix(fit_matrix_path)
+                                pred_matrix = load_matrix(pred_matrix_path)
+
+                                classify_matrix(
+                                    cluster_df=cluster_df,
+                                    pred_df=dih_df,
+                                    fit_matrix=fit_matrix,
+                                    pred_matrix=pred_matrix,
+                                    result_table_path=result_table_path,
+                                    max_nn_dist=0.45,
+                                    only_save_pred=True,
+                                    reorder_class=False,
+                                )
+                            else:
+                                result_df = dih_df.copy(deep=True)
+                                result_df[cluster_col] = noise_name
+                                save_table(result_table_path, result_df)
+
+                            result_df = load_table(result_table_path)
+
+                            loop_result_df = pd.concat(
+                                [loop_result_df, result_df], sort=False
+                            )
+                       
                 loop_result_table_path = get_file_path(
                     result_table_file, dir_str=loop_name, dir_path=out_path
                 )
@@ -335,21 +369,33 @@ def classify_rascore(file_paths, out_path=None, dih_dict=None, num_cpu=1):
                         result_dict
                     )
 
+                loop_result_df = loop_result_df.reset_index(drop=True)
+            
+                for index in list(loop_result_df.index.values):
+                    cluster = loop_result_df.at[index, cluster_col]
+                    if noise_name in cluster:
+                        complete =  str(loop_result_df.at[index, complete_col])
+                        if complete == str(True):
+                            cluster = outlier_name
+                        elif complete == str(False):
+                            cluster = disorder_name
+                        loop_result_df.at[index,cluster_col] = cluster
+
+                loop_sum_df = build_sum_table(loop_result_df)
+
                 save_table(loop_result_table_path, loop_result_df)
                 save_table(loop_sum_table_path, loop_sum_df)
 
                 loop_result_df = loop_result_df.rename(columns={cluster_col: loop_name})
 
-                loop_result_df = loop_result_df.loc[
-                    :, [core_path_col, modelid_col, chainid_col, loop_name]
-                ]
+                loop_result_df = loop_result_df.loc[:,[core_path_col, modelid_col, chainid_col, loop_name]]
 
                 df = merge_tables(df, loop_result_df)
 
-            if sw1_gtp_name in lst_col(df, sw1_name, unique=True):
+            if gtp_name in lst_col(df, nuc_class_col, unique=True):
                 dist_df = build_dist_table(
-                    mask_equal(df, sw1_name, sw1_gtp_name),
-                    x_resids=[32],
+                    mask_equal(df, nuc_class_col, gtp_name),
+                    x_resids=[y32_resid],
                     y_resids=[bio_lig_col],
                     x_atomids=["OH"],
                     y_atomids=[gtp_atomids],
@@ -357,41 +403,31 @@ def classify_rascore(file_paths, out_path=None, dih_dict=None, num_cpu=1):
                     check_hb=True,
                 )
 
-                dist_df[hb_status_col] = dist_df[hb_status_col].map(sw1_gtp_dict)
-
-                dist_df = dist_df.loc[
+                merge_df = dist_df.loc[
                     :, [core_path_col, modelid_col, chainid_col, hb_status_col]
                 ]
 
-                df = merge_tables(df, dist_df)
-
-                df[sw1_name].replace(
-                    {
-                        sw1_gtp_name: "",
-                        sw1_gtp_wat_name: "",
-                        sw1_gtp_dir_name: "",
-                        sw1_gtp_no_name: "",
-                    },
-                    inplace=True,
-                )
-                df[sw1_name] += df[hb_status_col].fillna("").map(str)
-
-                del df[hb_status_col]
+                df = merge_tables(df, merge_df)
 
             result_table_path = get_file_path(result_table_file, dir_path=out_path)
 
+            for col in list(df.columns):
+                df = fix_col(df, col)
+
             save_table(result_table_path, df)
 
-            for loop_name, loop_resids in loop_resid_dict.items():
+            for loop_name in [sw1_name,sw2_name]:
 
                 pymol_pml_path = get_file_path(
                     f"{loop_name}_{pymol_pml_file}", dir_path=out_path
                 )
 
                 if loop_name == sw1_name:
-                    stick_resids = [32]
+                    loop_resids = sw1_resids
+                    stick_resids = [y32_resid]
                 elif loop_name == sw2_name:
-                    stick_resids = [71]
+                    loop_resids = sw2_resids
+                    stick_resids = [y71_resid]
 
                 write_pymol_script(
                     df,
@@ -402,8 +438,8 @@ def classify_rascore(file_paths, out_path=None, dih_dict=None, num_cpu=1):
                     style_ribbon=True,
                     thick_bb=False,
                     show_bio=True,
-                    color_palette=conf_color_dict[loop_name],
                     sup_group=True,
+                    color_palette=conf_color_dict[loop_name],
                     sup_resids=sup_resids,
                     show_resids=show_resids,
                 )
