@@ -1,33 +1,26 @@
 # -*- coding: utf-8 -*-
 """
-MIT License
+  Copyright 2022 Mitchell Isaac Parker
 
-Copyright (c) 2022 Mitchell Isaac Parker
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
+       http://www.apache.org/licenses/LICENSE-2.0
 
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
 """
 
 import pandas as pd
 from tqdm import tqdm
 import concurrent.futures
 
-from ..functions.chem import is_lig_match, get_lig_simi
+from ..functions.chem import get_lig_smiles, is_lig_match, get_lig_simi
 from ..functions.lst import lst_unique, lst_to_str, res_to_lst, type_lst, sort_lst
 from ..functions.lig import lig_col_lst, lig_lst_dict
 from ..functions.coord import (
@@ -48,6 +41,8 @@ from ..functions.col import (
     pharm_lig_col,
     pharm_lig_site_col,
     pharm_lig_match_col,
+    pharm_lig_smiles_col,
+    bound_lig_cont_col
 )
 from ..functions.table import get_df_at_index, fix_val
 from ..functions.path import save_table
@@ -85,12 +80,14 @@ def build_lig_df(
     structure = load_coord(coord_path)
     neighbors = get_neighbors(structure[fix_val(modelid, return_int=True)][chainid])
 
+    cont_lst = list()
     site_lst = list()
     match_lst = list()
+    smiles_lst = list()
 
     for residue in get_residues(structure):
         if is_het(residue):
-            cont_lst = lst_unique(
+            resid_cont_lst = lst_unique(
                 [
                     get_resnum(x)
                     for x in get_residue_cont(
@@ -104,7 +101,8 @@ def build_lig_df(
                     and (is_aa(x))
                 ]
             )
-            if len(cont_lst) > 0:
+
+            if len(resid_cont_lst) > 0:
                 resname = get_resname(residue)
                 lig_class = False
                 is_pharm = False
@@ -119,18 +117,31 @@ def build_lig_df(
                     lig_dict[pharm_lig_col].append(resname)
                     is_pharm = True
 
+                resid_cont_str = resname
+                resid_cont_str += ':'
+                resid_cont_str += lst_to_str(resid_cont_lst)
+                cont_lst.append(resid_cont_str)
+
                 if is_pharm:
+                
                     if site_dict is not None:
+
                         max_cont = 0
                         pharm_site = other_site
                         for site_name, site_cont_lst in site_dict.items():
-                            site_cont = len([x for x in site_cont_lst if x in cont_lst])
+                            site_cont = len([x for x in site_cont_lst if x in resid_cont_lst])
                             if site_cont > max_cont:
                                 pharm_site = site_name
                                 max_cont = site_cont
                         site_lst.append(pharm_site)
 
                     if match_dict is not None:
+
+                        resid_smiles_str = resname
+                        resid_smiles_str += ':'
+                        resid_smiles_str += get_lig_smiles(resname, lig_dir=lig_dir)
+                        smiles_lst.append(resid_smiles_str)
+
                         if pharm_site in list(match_dict.keys()):
                             pharm_match = other_match
                             match_name_lst = list()
@@ -165,6 +176,8 @@ def build_lig_df(
     df.at[index, pharm_lig_match_col] = lst_to_str(
         sort_lst(lst_unique(match_lst)), join_txt="|", empty=none_match
     )
+    df.at[index, pharm_lig_smiles_col] = lst_to_str(smiles_lst, join_txt="|")
+    df.at[index, bound_lig_cont_col] = lst_to_str(cont_lst, join_txt="|")
 
     return df
 
@@ -184,6 +197,8 @@ def annot_lig(
     num_cpu=1,
 ):
 
+    df = df.reset_index(drop=True)
+
     if site_dict is not None:
         for site_name, site_cont in site_dict.items():
             site_dict[site_name] = res_to_lst(site_cont)
