@@ -1,26 +1,19 @@
 # -*- coding: utf-8 -*-
 """
-MIT License
+  Copyright 2022 Mitchell Isaac Parker
 
-Copyright (c) 2022 Mitchell Isaac Parker
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
 
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
+       http://www.apache.org/licenses/LICENSE-2.0
 
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
 """
 
 from ..functions.color import get_rgb, get_lst_colors
@@ -265,6 +258,7 @@ def write_pymol_script(
     color_atomic=True,
     show_resids=None,
     cartoon_transp=0,
+    surface_transp=1,
     show_bio=None,
     show_ion=None,
     show_pharm=None,
@@ -475,6 +469,9 @@ def write_pymol_script(
 
         chain_sele = f"model {obj} and chain {chainid}"
 
+        if surface_transp < 1:
+            pymol_file.write(f"show surface, {chain_sele}\n")
+
         if show_prot is not None and show_prot != False:
             if prot_chainid_col != bound_interf_chainid_col:
                 if prot_chainid != "None":
@@ -492,7 +489,7 @@ def write_pymol_script(
         hide_style = "cartoon"
         if style_ribbon:
             hide_style = "ribbon"
-        pymol_file.write(f"hide {hide_style}, not resi {show_resids}\n")
+        pymol_file.write(f"hide {hide_style}, not resi {show_resids}\n")       
 
     if stick_resids is not None:
         for stick_resid in stick_resid_lst:
@@ -524,6 +521,9 @@ def write_pymol_script(
 
             pymol_file.write(f"show sticks, {stick_sele}\n")
 
+    if surface_transp < 1:
+        pymol_file.write(f"set surface_color, {polymer_color}, (all)\n")
+
     if loop_resids is not None:
         for loop_range in loop_resid_lst:
 
@@ -547,6 +547,10 @@ def write_pymol_script(
                     pymol_file.write(f"hide cartoon,{loop_sele}\n")
                     if thick_bb:
                         pymol_file.write(f"show sticks, bb. and {loop_sele}\n")
+
+                if surface_transp < 1:
+                    pymol_file.write(f"set surface_color, {loop_range}_color, {loop_sele}\n")
+
             else:
                 for group in group_lst:
                     group_loop_sele = f"{group}_{loop_sele}"
@@ -567,6 +571,9 @@ def write_pymol_script(
                                 f"show sticks, bb. and {group_loop_sele}\n"
                             )
 
+                    if surface_transp < 1:
+                        pymol_file.write(f"set surface_color, {group}_color, {group_loop_sele}\n")
+
                 pymol_file.write(f"group {loop_sele}, *_{loop_sele}\n")
 
     if group_col is None:
@@ -910,6 +917,8 @@ def write_pymol_script(
 
     pymol_file.write(f"set cartoon_transparency, {cartoon_transp}\n")
 
+    pymol_file.write(f"set transparency, {surface_transp}\n")
+
     pymol_file.write("hide labels\n")
 
     pymol_file.write("zoom center, 25\n")
